# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/input.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api import data_pb2 as proto_dot_clarifai_dot_api_dot_data__pb2
from clarifai.rest.grpc.proto.clarifai.api import feedback_pb2 as proto_dot_clarifai_dot_api_dot_feedback__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_pb2 as proto_dot_clarifai_dot_api_dot_model__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/input.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1eproto/clarifai/api/input.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a proto/clarifai/api/concept.proto\x1a\x1dproto/clarifai/api/data.proto\x1a!proto/clarifai/api/feedback.proto\x1a\x1eproto/clarifai/api/model.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf6\x01\n\x05Input\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Data\x12\x31\n\rfeedback_info\x18\x03 \x01(\x0b\x32\x1a.clarifai.api.FeedbackInfo\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x06status\x18\x06 \x01(\x0b\x32\x1b.clarifai.api.status.Status\"T\n\x0fGetInputRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08input_id\x18\x02 \x01(\t\"q\n\x11ListInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x10\n\x08per_page\x18\x03 \x01(\r\x12\x0b\n\x03ids\x18\x04 \x03(\t\"i\n\x13StreamInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08per_page\x18\x02 \x01(\r\x12\x0f\n\x07last_id\x18\x03 \x01(\t\"i\n\x11PostInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12#\n\x06inputs\x18\x02 \x03(\x0b\x32\x13.clarifai.api.Input\"z\n\x12PatchInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12#\n\x06inputs\x18\x02 \x03(\x0b\x32\x13.clarifai.api.Input\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"W\n\x12\x44\x65leteInputRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08input_id\x18\x02 \x01(\t\"g\n\x13\x44\x65leteInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x12\n\ndelete_all\x18\x03 \x01(\x08\"\x95\x01\n\x18PostModelFeedbackRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.clarifai.api.Input\"f\n\x13SingleInputResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\"\n\x05input\x18\x02 \x01(\x0b\x32\x13.clarifai.api.Input\"l\n\x12MultiInputResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12)\n\x06inputs\x18\x02 \x03(\x0b\x32\x13.clarifai.api.InputB\x04\x80\xb5\x18\x01\"o\n\nInputCount\x12\x17\n\tprocessed\x18\x01 \x01(\rB\x04\x80\xb5\x18\x01\x12\x18\n\nto_process\x18\x02 \x01(\rB\x04\x80\xb5\x18\x01\x12\x14\n\x06\x65rrors\x18\x03 \x01(\rB\x04\x80\xb5\x18\x01\x12\x18\n\nprocessing\x18\x04 \x01(\rB\x04\x80\xb5\x18\x01\"q\n\x18SingleInputCountResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12(\n\x06\x63ounts\x18\x02 \x01(\x0b\x32\x18.clarifai.api.InputCount\"G\n\x14GetInputCountRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\"\xb9\x01\n\x17PostModelOutputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12#\n\x06inputs\x18\x04 \x03(\x0b\x32\x13.clarifai.api.Input\x12\"\n\x05model\x18\x05 \x01(\x0b\x32\x13.clarifai.api.Model\"\x8f\x01\n\x16ListModelInputsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\r\x12\x10\n\x08per_page\x18\x05 \x01(\rB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_concept__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_data__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_feedback__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_model__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='clarifai.api.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.Input.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='clarifai.api.Input.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feedback_info', full_name='clarifai.api.Input.feedback_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.Input.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modified_at', full_name='clarifai.api.Input.modified_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.Input.status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=576,
)


_GETINPUTREQUEST = _descriptor.Descriptor(
  name='GetInputRequest',
  full_name='clarifai.api.GetInputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetInputRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_id', full_name='clarifai.api.GetInputRequest.input_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=662,
)


_LISTINPUTSREQUEST = _descriptor.Descriptor(
  name='ListInputsRequest',
  full_name='clarifai.api.ListInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListInputsRequest.page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListInputsRequest.per_page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='clarifai.api.ListInputsRequest.ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=777,
)


_STREAMINPUTSREQUEST = _descriptor.Descriptor(
  name='StreamInputsRequest',
  full_name='clarifai.api.StreamInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.StreamInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.StreamInputsRequest.per_page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_id', full_name='clarifai.api.StreamInputsRequest.last_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=884,
)


_POSTINPUTSREQUEST = _descriptor.Descriptor(
  name='PostInputsRequest',
  full_name='clarifai.api.PostInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='clarifai.api.PostInputsRequest.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=991,
)


_PATCHINPUTSREQUEST = _descriptor.Descriptor(
  name='PatchInputsRequest',
  full_name='clarifai.api.PatchInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PatchInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='clarifai.api.PatchInputsRequest.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='clarifai.api.PatchInputsRequest.action', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1115,
)


_DELETEINPUTREQUEST = _descriptor.Descriptor(
  name='DeleteInputRequest',
  full_name='clarifai.api.DeleteInputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteInputRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_id', full_name='clarifai.api.DeleteInputRequest.input_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1117,
  serialized_end=1204,
)


_DELETEINPUTSREQUEST = _descriptor.Descriptor(
  name='DeleteInputsRequest',
  full_name='clarifai.api.DeleteInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='clarifai.api.DeleteInputsRequest.ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_all', full_name='clarifai.api.DeleteInputsRequest.delete_all', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1309,
)


_POSTMODELFEEDBACKREQUEST = _descriptor.Descriptor(
  name='PostModelFeedbackRequest',
  full_name='clarifai.api.PostModelFeedbackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelFeedbackRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelFeedbackRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.PostModelFeedbackRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='clarifai.api.PostModelFeedbackRequest.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1461,
)


_SINGLEINPUTRESPONSE = _descriptor.Descriptor(
  name='SingleInputResponse',
  full_name='clarifai.api.SingleInputResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleInputResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='clarifai.api.SingleInputResponse.input', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1565,
)


_MULTIINPUTRESPONSE = _descriptor.Descriptor(
  name='MultiInputResponse',
  full_name='clarifai.api.MultiInputResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiInputResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='clarifai.api.MultiInputResponse.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1675,
)


_INPUTCOUNT = _descriptor.Descriptor(
  name='InputCount',
  full_name='clarifai.api.InputCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processed', full_name='clarifai.api.InputCount.processed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_process', full_name='clarifai.api.InputCount.to_process', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors', full_name='clarifai.api.InputCount.errors', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processing', full_name='clarifai.api.InputCount.processing', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1788,
)


_SINGLEINPUTCOUNTRESPONSE = _descriptor.Descriptor(
  name='SingleInputCountResponse',
  full_name='clarifai.api.SingleInputCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleInputCountResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counts', full_name='clarifai.api.SingleInputCountResponse.counts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1903,
)


_GETINPUTCOUNTREQUEST = _descriptor.Descriptor(
  name='GetInputCountRequest',
  full_name='clarifai.api.GetInputCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetInputCountRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1905,
  serialized_end=1976,
)


_POSTMODELOUTPUTSREQUEST = _descriptor.Descriptor(
  name='PostModelOutputsRequest',
  full_name='clarifai.api.PostModelOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelOutputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelOutputsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.PostModelOutputsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='clarifai.api.PostModelOutputsRequest.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='clarifai.api.PostModelOutputsRequest.model', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2164,
)


_LISTMODELINPUTSREQUEST = _descriptor.Descriptor(
  name='ListModelInputsRequest',
  full_name='clarifai.api.ListModelInputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListModelInputsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.ListModelInputsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.ListModelInputsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListModelInputsRequest.page', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListModelInputsRequest.per_page', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2310,
)

_INPUT.fields_by_name['data'].message_type = proto_dot_clarifai_dot_api_dot_data__pb2._DATA
_INPUT.fields_by_name['feedback_info'].message_type = proto_dot_clarifai_dot_api_dot_feedback__pb2._FEEDBACKINFO
_INPUT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INPUT.fields_by_name['modified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INPUT.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_GETINPUTREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_STREAMINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTINPUTSREQUEST.fields_by_name['inputs'].message_type = _INPUT
_PATCHINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_PATCHINPUTSREQUEST.fields_by_name['inputs'].message_type = _INPUT
_DELETEINPUTREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_DELETEINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELFEEDBACKREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELFEEDBACKREQUEST.fields_by_name['input'].message_type = _INPUT
_SINGLEINPUTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEINPUTRESPONSE.fields_by_name['input'].message_type = _INPUT
_MULTIINPUTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTIINPUTRESPONSE.fields_by_name['inputs'].message_type = _INPUT
_SINGLEINPUTCOUNTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEINPUTCOUNTRESPONSE.fields_by_name['counts'].message_type = _INPUTCOUNT
_GETINPUTCOUNTREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELOUTPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELOUTPUTSREQUEST.fields_by_name['inputs'].message_type = _INPUT
_POSTMODELOUTPUTSREQUEST.fields_by_name['model'].message_type = proto_dot_clarifai_dot_api_dot_model__pb2._MODEL
_LISTMODELINPUTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['GetInputRequest'] = _GETINPUTREQUEST
DESCRIPTOR.message_types_by_name['ListInputsRequest'] = _LISTINPUTSREQUEST
DESCRIPTOR.message_types_by_name['StreamInputsRequest'] = _STREAMINPUTSREQUEST
DESCRIPTOR.message_types_by_name['PostInputsRequest'] = _POSTINPUTSREQUEST
DESCRIPTOR.message_types_by_name['PatchInputsRequest'] = _PATCHINPUTSREQUEST
DESCRIPTOR.message_types_by_name['DeleteInputRequest'] = _DELETEINPUTREQUEST
DESCRIPTOR.message_types_by_name['DeleteInputsRequest'] = _DELETEINPUTSREQUEST
DESCRIPTOR.message_types_by_name['PostModelFeedbackRequest'] = _POSTMODELFEEDBACKREQUEST
DESCRIPTOR.message_types_by_name['SingleInputResponse'] = _SINGLEINPUTRESPONSE
DESCRIPTOR.message_types_by_name['MultiInputResponse'] = _MULTIINPUTRESPONSE
DESCRIPTOR.message_types_by_name['InputCount'] = _INPUTCOUNT
DESCRIPTOR.message_types_by_name['SingleInputCountResponse'] = _SINGLEINPUTCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['GetInputCountRequest'] = _GETINPUTCOUNTREQUEST
DESCRIPTOR.message_types_by_name['PostModelOutputsRequest'] = _POSTMODELOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['ListModelInputsRequest'] = _LISTMODELINPUTSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), dict(
  DESCRIPTOR = _INPUT,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Input)
  ))
_sym_db.RegisterMessage(Input)

GetInputRequest = _reflection.GeneratedProtocolMessageType('GetInputRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINPUTREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetInputRequest)
  ))
_sym_db.RegisterMessage(GetInputRequest)

ListInputsRequest = _reflection.GeneratedProtocolMessageType('ListInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListInputsRequest)
  ))
_sym_db.RegisterMessage(ListInputsRequest)

StreamInputsRequest = _reflection.GeneratedProtocolMessageType('StreamInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.StreamInputsRequest)
  ))
_sym_db.RegisterMessage(StreamInputsRequest)

PostInputsRequest = _reflection.GeneratedProtocolMessageType('PostInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostInputsRequest)
  ))
_sym_db.RegisterMessage(PostInputsRequest)

PatchInputsRequest = _reflection.GeneratedProtocolMessageType('PatchInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _PATCHINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PatchInputsRequest)
  ))
_sym_db.RegisterMessage(PatchInputsRequest)

DeleteInputRequest = _reflection.GeneratedProtocolMessageType('DeleteInputRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEINPUTREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteInputRequest)
  ))
_sym_db.RegisterMessage(DeleteInputRequest)

DeleteInputsRequest = _reflection.GeneratedProtocolMessageType('DeleteInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteInputsRequest)
  ))
_sym_db.RegisterMessage(DeleteInputsRequest)

PostModelFeedbackRequest = _reflection.GeneratedProtocolMessageType('PostModelFeedbackRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELFEEDBACKREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelFeedbackRequest)
  ))
_sym_db.RegisterMessage(PostModelFeedbackRequest)

SingleInputResponse = _reflection.GeneratedProtocolMessageType('SingleInputResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEINPUTRESPONSE,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleInputResponse)
  ))
_sym_db.RegisterMessage(SingleInputResponse)

MultiInputResponse = _reflection.GeneratedProtocolMessageType('MultiInputResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTIINPUTRESPONSE,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiInputResponse)
  ))
_sym_db.RegisterMessage(MultiInputResponse)

InputCount = _reflection.GeneratedProtocolMessageType('InputCount', (_message.Message,), dict(
  DESCRIPTOR = _INPUTCOUNT,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.InputCount)
  ))
_sym_db.RegisterMessage(InputCount)

SingleInputCountResponse = _reflection.GeneratedProtocolMessageType('SingleInputCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEINPUTCOUNTRESPONSE,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleInputCountResponse)
  ))
_sym_db.RegisterMessage(SingleInputCountResponse)

GetInputCountRequest = _reflection.GeneratedProtocolMessageType('GetInputCountRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINPUTCOUNTREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetInputCountRequest)
  ))
_sym_db.RegisterMessage(GetInputCountRequest)

PostModelOutputsRequest = _reflection.GeneratedProtocolMessageType('PostModelOutputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELOUTPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelOutputsRequest)
  ))
_sym_db.RegisterMessage(PostModelOutputsRequest)

ListModelInputsRequest = _reflection.GeneratedProtocolMessageType('ListModelInputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMODELINPUTSREQUEST,
  __module__ = 'proto.clarifai.api.input_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListModelInputsRequest)
  ))
_sym_db.RegisterMessage(ListModelInputsRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_MULTIINPUTRESPONSE.fields_by_name['inputs'].has_options = True
_MULTIINPUTRESPONSE.fields_by_name['inputs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_INPUTCOUNT.fields_by_name['processed'].has_options = True
_INPUTCOUNT.fields_by_name['processed']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_INPUTCOUNT.fields_by_name['to_process'].has_options = True
_INPUTCOUNT.fields_by_name['to_process']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_INPUTCOUNT.fields_by_name['errors'].has_options = True
_INPUTCOUNT.fields_by_name['errors']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_INPUTCOUNT.fields_by_name['processing'].has_options = True
_INPUTCOUNT.fields_by_name['processing']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
# @@protoc_insertion_point(module_scope)



import sys

from setuptools import find_packages

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

has_enum = sys.version_info >= (3, 4)

setup(
    name="clarifai",
    description='Clarifai API Python Client',
    version='2.3.1',
    author='Clarifai',
    maintainer='Robert Wen',
    maintainer_email='robert@clarifai.com',
    url='https://github.com/clarifai/clarifai-python',
    author_email='support@clarifai.com',
    install_requires=['future>=0.15, <2',
                      'requests>=2.13, <3',
                      'configparser>=3.5, <4',
                      'jsonschema>=2.5, <3',
                      'grpcio>=1.13.0, <2',
                      'protobuf>=3.6, <4'] +
                     ([] if has_enum else ['enum34>=1.1, <2']),
    packages=find_packages(),
    license="Apache 2.0",
    scripts=['scripts/clarifai'],
)



import unittest

from clarifai.rest.grpc.grpc_json_channel import dict_to_protobuf
from clarifai.rest.grpc.proto.clarifai.api.concept_pb2 import Concept as ConceptPB


class TestJsonToProtobuf(unittest.TestCase):
  _multiprocess_can_split_ = True

  def test_concept_with_no_value(self):
    converted = dict_to_protobuf(ConceptPB, {'id': 'some-id', 'name': 'Some Name'})
    assert converted.value == 1.0

  def test_concept_with_value_non_zero(self):
    converted = dict_to_protobuf(ConceptPB, {'id': 'some-id', 'name': 'Some Name', 'value': 0.5})
    assert converted.value == 0.5

  def test_concept_with_value_zero(self):
    converted = dict_to_protobuf(ConceptPB, {'id': 'some-id', 'name': 'Some Name', 'value': 0.0})
    assert converted.value == 0.0

  def test_concept_with_value_one(self):
    converted = dict_to_protobuf(ConceptPB, {'id': 'some-id', 'name': 'Some Name', 'value': 1.0})
    assert converted.value == 1.0



# -*- coding: utf-8 -*-
import copy
import json
import logging
import re
from pprint import pformat

import requests

from clarifai.errors import ApiError
from clarifai.rest.grpc.custom_converters.custom_dict_to_message import dict_to_protobuf
from clarifai.rest.grpc.custom_converters.custom_message_to_dict import protobuf_to_dict
from clarifai.rest.grpc.proto.clarifai.api.endpoint_pb2 import _V2
from clarifai.versions import CLIENT_VERSION, OS_VER, PYTHON_VERSION

BASE_URL = "https://api.clarifai.com"
URL_TEMPLATE_PARAM_REGEX = re.compile(r'\{{1}(.*?)\}{1}')

logger = logging.getLogger('clarifai')


class GRPCJSONChannel(object):
  """ This mimics the behaviour of a grpc channel object but allows transport over https with
  json request and response bodies.

  Currently there is only support for unary_unary requests. If you have any other type of grpc
  request this channel will nicely fail when trying to use within a grpc stub.

  Example:
    Assuming your top level endpoints are called V2 and in a proto/clarifai/api/endpoint.proto file,
    then you build those in python and can import the spec to use in GRPCJSONChannel as follows:

    from clarifai.rest.grpc.proto.clarifai.api.endpoint_pb2_grpc import V2Stub
    from clarifai.rest.grpc.proto.clarifai.api.endpoint_pb2 import _V2
    channel = GRPCJSONChannel(key="api key", service_descriptor=_V2)
    stub = V2Stub(channel)

    # Then you can use the stub to call just like grpc directly!!!
    result = stub.PostInputs(PostInputsRequest(inputs=[Input(data=Data(image=Image(
      url="http://...")))]))
  """

  def __init__(self, key, base_url=BASE_URL, service_descriptor=_V2):
    """
    Args:
      key: a string api key to use in the {"Authorization": "Key %s" % key} headers to send in each
    request.
      base_url: if you want to point at a different url than the default.
      service_description: This is a ServiceDescriptor object found in the compiled grpc-gateway
    .proto results. For example if your proto defining the endpoints is in endpoint.proto then look
    in endpoint_pb2.py file for ServiceDescriptor and use that.
    """
    self.base_url = base_url
    self.key = key
    self.name_to_resources = {}

    for m in service_descriptor.methods:
      # This gets the google.api.http object from the .proto file that looks like this:
      # option (google.api.http) = {
      #   delete: "/v2/users/{user_app_id.user_id}/apps/{user_app_id.app_id}/models/{model_id}"
      #   additional_bindings {
      #     delete: "/v2/models/{model_id}"
      #   }
      # Then we check if there are additional_bindings and use that if so (because we've had the
      # convention of having the default urls in there and the not yet used urls at the top level.

      base_http_rule = m.GetOptions().ListFields()[0][1]

      protobuf_name = '/' + service_descriptor.full_name + '/' + m.name
      self.name_to_resources[protobuf_name] = (m.input_type, [])

      for http_rule in base_http_rule.additional_bindings or [base_http_rule]:
        # Get the url template and the method to use for http.
        if http_rule.HasField('get'):
          method = 'GET'
          url_template = base_url + http_rule.get
        elif http_rule.HasField('post'):
          method = 'POST'
          url_template = base_url + http_rule.post
        elif http_rule.HasField('patch'):
          method = 'PATCH'
          url_template = base_url + http_rule.patch
        elif http_rule.HasField('put'):
          method = 'PUT'
          url_template = base_url + http_rule.put
        elif http_rule.HasField('delete'):
          method = 'DELETE'
          url_template = base_url + http_rule.delete
        else:
          raise Exception("Failed to parse the grpc-gateway service spec.")

        self.name_to_resources[protobuf_name][1].append((url_template, method))

  def unary_unary(self, name, request_serializer, response_deserializer):
    """ Method to create the callable JSONUnaryUnary. """
    request_message_descriptor, resources = self.name_to_resources[name]
    return JSONUnaryUnary(self.key, request_message_descriptor, resources, request_serializer,
                          response_deserializer)


class JSONUnaryUnary(object):
  """ This mimics the unary_unary calls and is actually the thing doing the http requests.
  """

  def __init__(self, key, request_message_descriptor, resources, request_serializer,
               response_deserializer):
    """
    Args:
      key: a string api key to use in the {"Authorization": "Key %s" % key} headers to send in each
           request.
      request_message_descriptor: this is a MessageDescriptor for the input type.
      resources: a list of available resource endpoints
      request_serializer: the method to use to serialize the request proto
      response_deserializer: the response proto deserializer which will be used to convert the http
                             response will be parsed into this.

    Returns:
      response: a proto object of class response_deserializer filled in with the response.
    """
    self.key = key
    self.request_message_descriptor = request_message_descriptor
    self.resources = resources
    self.request_serializer = request_serializer
    self.response_deserializer = response_deserializer
    self.headers = {"Authorization": "Key %s" % key}

  def __call__(self, request, metadata=None):
    """ This is where the actually calls come through when the stub is called such as
    stub.PostInputs(). They get passed to this method which actually makes the request.

    Args:
      request: the proto object for the request. It must be the proper type for the request or the
        server will complain. Note: this doesn't type check the incoming request in the client but
        does make sure it can serialize before sending to the server atleast.
      metadata: not used currently, just added to match grpc.

    Returns:
      response: the proto object that this method returns.
    """
    if metadata is not None:
      raise Exception("No support currently for metadata field.")

    # There is no __self__ attribute on the request_serializer unfortunately.
    expected_object_name = self.request_message_descriptor.name
    if type(request).__name__ != expected_object_name:
      raise Exception("The input request must be of type: %s from %s" %
                      (expected_object_name, self.request_message_descriptor.file.name))

    params = protobuf_to_dict(request)

    url, method = _pick_proper_endpoint(self.resources, params)

    headers = {
        'Content-Type': 'application/json',
        'X-Clarifai-Client': 'python:%s' % CLIENT_VERSION,
        'Python-Client': '%s:%s' % (OS_VER, PYTHON_VERSION),
        'Authorization': self.headers['Authorization']
    }

    logger.debug("=" * 100)
    succinct_payload = _mangle_base64_values(params)
    logger.debug("%s %s\nHEADERS:\n%s\nPAYLOAD:\n%s", method, url, pformat(headers),
                 pformat(succinct_payload))

    if method == 'GET':
      res = requests.get(url, params=params, headers=headers)
    elif method == "POST":
      res = requests.post(url, data=json.dumps(params), headers=headers)
    elif method == "DELETE":
      res = requests.delete(url, data=json.dumps(params), headers=headers)
    elif method == "PATCH":
      res = requests.patch(url, data=json.dumps(params), headers=headers)
    elif method == "PUT":
      res = requests.put(url, data=json.dumps(params), headers=headers)
    else:
      raise Exception("Unsupported request type: '%s'" % method)

    try:
      response_json = json.loads(res.content.decode('utf-8'))
    except ValueError:
      logger.exception("Could not get valid JSON from server response.")
      logger.debug("\nRESULT:\n%s", pformat(res.content.decode('utf-8')))
      return res
    else:
      logger.debug("\nRESULT:\n%s", pformat(response_json))

    if int(res.status_code / 100) != 2:
      error = ApiError(url, params, method, res)
      logger.warn("%s", str(error))
      raise error

    # Get the actual message object to construct
    message = self.response_deserializer
    result = dict_to_protobuf(message, response_json)

    return result


def _mangle_base64_values(params):
  """ Mangle (shorten) the base64 values because they are too long for output. """
  inputs = (params or {}).get('inputs')
  query = (params or {}).get('query')
  if inputs and len(inputs) > 0:
    return _mangle_base64_values_in_inputs(params)
  if query and query.get('ands'):
    return _mangle_base64_values_in_query(params)
  return params


def _mangle_base64_values_in_inputs(params):
  params_copy = copy.deepcopy(params)
  for data in params_copy['inputs']:
    data = data['data']
    image = data.get('image')
    if image and image.get('base64'):
      image['base64'] = _shortened_base64_value(image['base64'])

    video = data.get('video')
    if video and video.get('base64'):
      video['base64'] = _shortened_base64_value(video['base64'])
  return params_copy


def _mangle_base64_values_in_query(params):
  params_copy = copy.deepcopy(params)
  queries = params_copy['query']['ands']
  for query in queries:
    image = query.get('output', {}).get('input', {}).get('data', {}).get('image', {})
    base64_val = image.get('base64')
    if base64_val:
      image['base64'] = _shortened_base64_value(base64_val)
  return params_copy


def _shortened_base64_value(original_base64):
  # Shorten the value if larger than what we shorten to (10 + 6 + 10).
  if len(original_base64) > 36:
    return original_base64[:10] + '......' + original_base64[-10:]
  else:
    return original_base64


def _pick_proper_endpoint(resources, request_dict):
  """
  Fills in the url template with the actual url params from the request body.
  Picks the most appropriate url depending on which parameters are present in the request body.
  Args:
    resources: all available resource endpoints for this method.
    request_dict: a dictionary form of the request from json_format.MessageToDict(request,
                  preserving_proto_field_name=True) so that we can recursively lookup url params.
  Returns:
    url: the url string to use in requests.
    method: one of get/post/patch/delete.
  """

  best_match_url = None
  best_match_method = None
  best_match_count = -1

  all_fields = []
  for url_template, method in resources:
    all_arguments_translated = True

    url = url_template
    count = 0
    for field in re.findall(URL_TEMPLATE_PARAM_REGEX, url_template):
      all_fields.append(field)

      field_value = request_dict.get(field.split('.')[-1])
      if not field_value:
        all_arguments_translated = False
        break

      count += 1

      url = url.replace('{' + field + '}', field_value)

    if all_arguments_translated:
      if best_match_count < count:
        best_match_url = url
        best_match_method = method
        best_match_count = count

  if not best_match_url:
    raise Exception("You must set one case of the following fields in your request proto: "
                    "%s" % all_fields)

  return best_match_url, best_match_method
